package com.duanledexianxianxian.data.process;

import com.google.common.collect.Lists;
import com.google.common.collect.Maps;
import com.google.common.collect.Sets;
import com.sun.org.apache.regexp.internal.RE;
import org.apache.commons.collections4.CollectionUtils;
import org.apache.commons.io.FileUtils;
import org.apache.commons.lang3.StringUtils;

import java.io.File;
import java.io.IOException;
import java.util.*;

/**
 * @author duanledexianxianxian
 */
public class Application {
    private static Set<Model> errorSet = Sets.newHashSet();

    public static void main(String[] args) throws IOException {
        List<String> lines = readData();

        // 中文数据
        String zh = processData(lines, 0);
        writeData("F:\\@project@\\@dianli@\\java-demo\\data-process\\src\\main\\resources\\zh.sql", zh);
        // 英文数据
        String en = processData(lines, 1);
        writeData("F:\\@project@\\@dianli@\\java-demo\\data-process\\src\\main\\resources\\en.sql", en);

        System.out.println("error data");
       for (Model model:errorSet){
           System.out.println(model);
       }
    }

    private static void writeData(String fileName, String content) throws IOException {
        FileUtils.write(new File(fileName), content, "UTF-8");
    }

    private static List<String> readData() throws IOException {
        File file = new File("F:\\@project@\\@dianli@\\java-demo\\data-process\\src\\main\\resources\\省市区码表.csv");
        List<String> lines = FileUtils.readLines(file, "UTF-8");
        System.out.println("lines:" + lines);
        return lines;
    }


    private static String processData(List<String> lines, int lang) {
        List<Model> modelList = Lists.newLinkedList();
        Map<String, Model> provinceMap = Maps.newTreeMap();
        Map<String, Model> allMap = Maps.newHashMap();
        int[] index = {lang == 0 ? 100000 : 200000};
        if (CollectionUtils.isNotEmpty(lines)) {
            lines.forEach(x -> {
                String[] words = StringUtils.split(x, "@");
                System.out.println("words:" + Arrays.toString(words));
                Model model;
                model = new Model();
                model.setId((long) index[0]);
                model.setGrade(words[0]);
                model.setType(Integer.parseInt(words[0]));
                model.setNameCn(words[1]);
                model.setNameEn(words[2]);
                model.setOrders(words[3]);
                model.setRegCode(words[4]);
                if (words.length <= 5) {
                    model.setPId(lang == 0 ? 1L : 242L);
                    provinceMap.put(model.getRegCode(), model);
                } else {
                    model.setBelongTo(words[5]);
                    model.setPRegCode(words[6]);
                }
                allMap.put(model.getRegCode(), model);
                modelList.add(model);
                index[0]++;
            });
        }

        System.out.println("modelList:" + modelList);
        System.out.println("provinceMap:" + provinceMap);
        System.out.println("allMap:" + allMap);

        modelList.forEach(x -> {
            if (allMap.containsKey(x.getPRegCode())) {
                x.setPId(allMap.get(x.getPRegCode()).getId());
            }
        });

        // 排个序
        System.out.println("modelList:" + modelList);
        Collections.sort(modelList, (o1, o2) -> {
            Integer result = o1.getType() - o2.getType();
            if (result.equals(0)) {
                return o1.getRegCode().compareTo(o2.getRegCode());
            }
            return result;
        });
        System.out.println("sort modelList" + modelList);

        StringBuffer sb = new StringBuffer();
        modelList.forEach(x -> {
            if (null != x.getPId()) {
                sb.append(String.format("INSERT INTO `tsys_business_parameter_geography`(`id`, `pId`, `local`, `district_code`, `district_name`, `type`, `is_delete`, `creator_id`, `create_time`, `editor_id`, `edit_time`) VALUES " +
                                "(\"%d\", \"%d\", \"%s\", \"%s\", \"%s\", \"%d\", 0, 1, now(), NULL, NULL);\n",
                        x.getId(), x.getPId(), lang == 0 ? "zh-cn" : "en-us", x.getRegCode(), lang == 0 ? x.getNameCn() : x.getNameEn(), x.getType()));

            } else {
                errorSet.add(x);
            }
        });
        System.out.println(sb);
        return sb.toString();
    }

}
